antares.apps.document.api package
=================================

Submodules
----------

antares.apps.document.api.api\_document\_submit\_view module
------------------------------------------------------------

.. automodule:: antares.apps.document.api.api_document_submit_view
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.document.api.api\_document\_upload\_view module
------------------------------------------------------------

.. automodule:: antares.apps.document.api.api_document_upload_view
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.document.api
   :members:
   :undoc-members:
   :show-inheritance:
